import {
  isBoolean,
  isFunction,
  isNumber,
  isObject,
  isString
} from "./chunk-V5ZQ2SFQ.js";

// src/common/schema/index.ts
function preParse(obj, info) {
  if (obj == null) {
    if (info._default != null) {
      if (isFunction(info._default))
        obj = info._default();
      else
        obj = info._default;
    }
  }
  if (obj == null && info._optional === true)
    return void 0;
  if (obj == null)
    throw new Error("cannot be undefined");
  if (!info._check || info._check(obj))
    return obj;
  throw new Error("wrong value");
}
function generic(type, opt) {
  const info = {
    parse(obj) {
      return preParse(obj, this);
    },
    ...opt,
    type,
    optional() {
      this._optional = true;
      return this;
    },
    default(value) {
      this._default = value;
      return this;
    }
  };
  return info;
}
function string(opt) {
  return generic("string", {
    ...opt,
    _check: isString
  });
}
function number(opt) {
  return generic("number", {
    ...opt,
    _check: isNumber
  });
}
function boolean(opt) {
  return generic("boolean", {
    ...opt,
    _check: isBoolean
  });
}
function object(tobj, opt) {
  const info = generic("object", {
    ...opt,
    _object: tobj,
    parse(obj) {
      if (obj == null && this._optional === true)
        return void 0;
      const newObj = {};
      if (!isObject(obj))
        return new Error("expected object input");
      if (!isObject(this._object))
        return new Error("expected object definition");
      for (const [key, info2] of Object.entries(this._object)) {
        const value = info2.parse(obj[key]);
        if (value !== void 0)
          newObj[key] = value;
      }
      return newObj;
    }
  });
  return info;
}

export {
  string,
  number,
  boolean,
  object
};
//# sourceMappingURL=chunk-6VZD6A2S.js.map