import {
  isPromise
} from "./chunk-L324TYGN.js";
import {
  DAY_MS
} from "./chunk-5DS3NT57.js";

// src/common/data/day-legacy.ts
var Day = class _Day {
  get value() {
    return this.days;
  }
  constructor(days) {
    if (typeof days === "number") {
      this.days = days;
      return;
    }
    if (days != null)
      days = _Day.from(days)?.days;
    if (days == null) {
      const date = /* @__PURE__ */ new Date();
      this.days = date.getFullYear() * 1e4 + (date.getMonth() + 1) * 100 + date.getDate();
    } else {
      this.days = days;
    }
  }
  static fromNumber(n) {
    return new _Day(n);
  }
  static fromString(dateString) {
    return _Day.from(+dateString.replace(/\D/g, "").slice(0, 8));
  }
  static fromDate(date, utc = false) {
    return utc ? _Day.fromString(date.toISOString().substr(0, 10)) : _Day.from(
      date.getFullYear() * 1e4 + (date.getMonth() + 1) * 100 + date.getDate()
    );
  }
  static fromDateUTC(date) {
    return _Day.fromDate(date, true);
  }
  /** @deprecated use fromDateUTC */
  static fromDateGMT(date) {
    return _Day.fromDate(date, true);
  }
  static from(value, utc = false) {
    if (typeof value === "number") {
      if (value < 100)
        return;
      return new _Day(value);
    } else if (typeof value === "string") {
      return _Day.fromString(value);
    } else if (Array.isArray(value) && value.length === 3) {
      const [year, month = 1, day2 = 1] = value;
      if (month < 1 || month > 12 || day2 < 1 || day2 > 31)
        return;
      return new _Day(year * 1e4 + month * 100 + day2);
    } else if (value instanceof Date) {
      return _Day.fromDate(value, utc);
    } else if (value instanceof _Day) {
      return value;
    }
  }
  toNumber() {
    return this.days;
  }
  // Transformer
  /** Just for future extensions */
  toJson() {
    return this.days;
  }
  toString(sep = "-") {
    const baseString = String(this.days);
    return baseString.slice(0, 4) + sep + baseString.slice(4, 6) + sep + baseString.slice(6, 8);
  }
  toDate(utc = false) {
    return utc ? /* @__PURE__ */ new Date(`${this.toString()}T00:00:00.000Z`) : new Date(
      this.days / 1e4,
      // year
      this.days / 100 % 100 - 1,
      // month
      this.days % 100
      // day
    );
  }
  toDateUTC() {
    return this.toDate(true);
  }
  /** @deprecated use toDateUTC */
  toDateGMT() {
    return this.toDate(true);
  }
  get year() {
    return Math.floor(this.days / 1e4);
  }
  get month() {
    return Math.floor(this.days / 100 % 100);
  }
  get day() {
    return Math.floor(this.days % 100);
  }
  // Calculations
  dayOffset(offset) {
    return _Day.fromDateUTC(
      new Date(this.toDateUTC().getTime() + offset * DAY_MS)
    );
  }
  monthStart() {
    return _Day.from([this.year, this.month, 1]);
  }
  yearStart() {
    return _Day.from([this.year, 1, 1]);
  }
  /** Very stupid approach, only works for days <= 28 */
  monthOffset(offset) {
    const m = this.month + offset;
    let mm = Math.floor((m - 1) % 12) + 1;
    if (mm === 0)
      mm = 12;
    const yy = Math.floor((m - 1) / 12);
    return _Day.from([this.year + yy, mm, this.day]);
  }
  daysUntil(otherDay) {
    return Math.round(
      (new _Day(otherDay)?.toDateUTC().getTime() - this.toDateUTC().getTime()) / DAY_MS
    );
  }
  // Shortcuts
  yesterday() {
    return this.dayOffset(-1);
  }
  tomorrow() {
    return this.dayOffset(1);
  }
};
async function forEachDay(from, to, handler) {
  let start = Day.from(from);
  const end = Day.from(to);
  while (start && end && start?.days <= end?.days) {
    const result = handler(start);
    if (isPromise(result))
      await result;
    start = start.dayOffset(1);
  }
}
function today() {
  return new Day();
}
function day(days) {
  return new Day(days);
}
function dateStringToDays(dateString) {
  return Day.fromDate(new Date(dateString)).days;
}

export {
  Day,
  forEachDay,
  today,
  day,
  dateStringToDays
};
//# sourceMappingURL=chunk-C7K2ID3C.js.map