// src/node/env.ts
import fs from "node:fs";
import { resolve } from "node:path";
import process from "node:process";
var NEWLINE = "\n";
var RE_INI_KEY_VAL = /^\s*([\w.-]+)\s*=\s*(.*)\s*$/;
var RE_NEWLINES = /\\n/g;
var NEWLINES_MATCH = /\r\n|\n|\r/;
function parse(src, _options = {}) {
  const obj = {};
  String(src).split(NEWLINES_MATCH).forEach((line, idx) => {
    const keyValueArr = line.match(RE_INI_KEY_VAL);
    if (keyValueArr != null) {
      const key = keyValueArr[1];
      let val = keyValueArr[2] || "";
      const end = val.length - 1;
      const isDoubleQuoted = val[0] === '"' && val[end] === '"';
      const isSingleQuoted = val[0] === "'" && val[end] === "'";
      if (isSingleQuoted || isDoubleQuoted) {
        val = val.substring(1, end);
        if (isDoubleQuoted)
          val = val.replace(RE_NEWLINES, NEWLINE);
      } else {
        val = val.trim();
      }
      obj[key] = val;
    }
  });
  return obj;
}
function stringToPath(value, defaultValue = ".") {
  return resolve(process.cwd(), value ?? defaultValue);
}
function valueToPath(value, defaultValue = "") {
  if (value == null)
    value = defaultValue;
  return stringToPath(String(value).trim(), defaultValue);
}
var toPath = valueToPath;
function getEnvVariableRelaxed(name, env = process.env) {
  if (env[name] != null)
    return env[name];
  name = name.toLowerCase();
  for (const [k, v] of Object.entries(env)) {
    if (k.toLowerCase() === name)
      return v;
  }
}
function setupEnv(options = {}) {
  const dotenvPath = options?.path ?? toPath(options?.filename ?? ".env");
  const encoding = options?.encoding ?? "utf8";
  const debug = options?.debug || false;
  try {
    let envOf2 = function(name) {
      return fs.existsSync(name) ? parse(fs.readFileSync(name, { encoding }), { debug }) : {};
    };
    var envOf = envOf2;
    const parsed = {};
    Object.assign(
      parsed,
      envOf2(dotenvPath),
      envOf2(`${dotenvPath}.local`)
    );
    if (options.mode) {
      Object.assign(
        parsed,
        envOf2(`${dotenvPath}.${options.mode}`),
        envOf2(`${dotenvPath}.${options.mode}.local`)
      );
    }
    const env = options?.env ?? process.env;
    Object.entries(parsed).forEach(([key, value]) => {
      if (typeof options?.prefix === "string")
        key = options?.prefix + key;
      if (!Object.prototype.hasOwnProperty.call(env, key)) {
        if (value != null)
          env[key] = value;
      }
    });
    return { parsed };
  } catch (e) {
    return { error: e };
  }
}

export {
  stringToPath,
  valueToPath,
  toPath,
  getEnvVariableRelaxed,
  setupEnv
};
//# sourceMappingURL=chunk-YIU6EKNX.js.map