interface StatsBase {
    isFile: () => boolean;
    isDirectory: () => boolean;
    isBlockDevice: () => boolean;
    isCharacterDevice: () => boolean;
    isSymbolicLink: () => boolean;
    isFIFO: () => boolean;
    isSocket: () => boolean;
    dev: number;
    ino: number;
    mode: number;
    nlink: number;
    uid: number;
    gid: number;
    rdev: number;
    size: number;
    blksize: number;
    blocks: number;
    atimeMs: number;
    mtimeMs: number;
    ctimeMs: number;
    birthtimeMs: number;
    atime: Date;
    mtime: Date;
    ctime: Date;
    birthtime: Date;
}
/**
 * Retrieves the file system stats for the specified path asynchronously.
 * @param path - The path to the file or directory.
 * @returns A Promise that resolves to the file system stats (Stats) or undefined if an error occurs.
 */
declare function getStatAsync(path: string): Promise<StatsBase | undefined>;
/**
 * Retrieves the fingerprint of a file asynchronously.
 * The fingerprint is a string representation of the file's path, modification time, and size.
 *
 * @param path - The path of the file.
 * @returns A promise that resolves to the fingerprint string, or undefined if the file does not exist.
 */
declare function getFingerprintAsync(path: string): Promise<string | undefined>;
declare function walkSyncAsync(rootFolder: string, subFolder?: string, ignoreHidden?: boolean): Promise<string[]>;
declare function filesAsync(opt?: {
    basePath?: string;
    pattern?: string | RegExp;
    filter?: (name: string) => boolean;
    ignoreHidden?: boolean;
}): Promise<string[]>;

export { filesAsync, getFingerprintAsync, getStatAsync, walkSyncAsync };
