import {
  filesAsync,
  getFingerprintAsync,
  getStatAsync
} from "../chunk-JPTP6WJC.js";
import "../chunk-QU4LUB3H.js";
import "../chunk-EGXUCKU4.js";
import "../chunk-52W67DTK.js";
import "../chunk-UMUHNSGZ.js";
import "../chunk-XBO3LADP.js";
import "../chunk-6VZD6A2S.js";
import "../chunk-SPKWNIPO.js";
import "../chunk-DVBRAJ3X.js";
import "../chunk-VK3HQ7U6.js";
import "../chunk-GKKLBSFA.js";
import "../chunk-RNL46FQ3.js";
import "../chunk-MWUFUBY5.js";
import "../chunk-FLFB2K34.js";
import "../chunk-264HKVNG.js";
import "../chunk-H2GCNFWS.js";
import "../chunk-AJCIHTGI.js";
import "../chunk-HST4VI64.js";
import "../chunk-A7SUGWC3.js";
import "../chunk-M6NJWFDP.js";
import "../chunk-6B24OWYC.js";
import "../chunk-KDP637GO.js";
import "../chunk-A4L4FO52.js";
import "../chunk-NEEIRLS6.js";
import "../chunk-WZDTE5W3.js";
import "../chunk-VBSEGKT7.js";
import "../chunk-Q3QHD23G.js";
import "../chunk-CYDFP47V.js";
import "../chunk-URTIMVUU.js";
import "../chunk-DXM327S3.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-NLNCD3ES.js";
import "../chunk-BMLTMNZA.js";
import "../chunk-7QYVSWCZ.js";
import "../chunk-VI7IQ5ZG.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-AN7WCP7S.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-2DAGZ4FT.js";
import "../chunk-3MLDC2KV.js";
import "../chunk-7G6NITL4.js";
import "../chunk-RSLTBO5X.js";
import "../chunk-I45WP5PM.js";
import "../chunk-MIZOLME5.js";
import "../chunk-AKLYUMQO.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-3KKFLSLG.js";
import "../chunk-PLBFBDKH.js";
import "../chunk-2H4XRKWS.js";
import "../chunk-WJUQ3VXF.js";
import "../chunk-O4GTSXBN.js";
import "../chunk-2OUSR2BE.js";
import "../chunk-ZDZ4EQHN.js";
import "../chunk-PZP2B3FC.js";
import "../chunk-NSJKG6AJ.js";
import "../chunk-XHPHUZE4.js";
import "../chunk-NRGUBMFA.js";
import "../chunk-H564H42Z.js";
import "../chunk-PE4JT3J7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-LAWEUL6N.js";
import "../chunk-V5ZQ2SFQ.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-EDNCPFSF.js";
import "../chunk-73CVRDI7.js";
import "../chunk-3KQS63H6.js";
import "../chunk-C7K2ID3C.js";
import "../chunk-L324TYGN.js";
import "../chunk-5DS3NT57.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-UO7L7NBK.js";
import "../chunk-QUQRUDWG.js";
import "../chunk-ITJJZ6AV.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-GY34N3KU.js";
import "../chunk-X56GIAWQ.js";
import "../chunk-PN34O4SN.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-HJ22ULAI.js";
import "../chunk-EJGW3W3K.js";
import "../chunk-EAYWSLQT.js";
import "../chunk-I7BWSAN6.js";

// src/node/files-async.spec.ts
describe("getStatAsync", () => {
  it("should return the stat object for a valid path", async () => {
    const path = __filename;
    const statObject = await getStatAsync(path);
    expect(statObject).toBeDefined();
    expect(statObject.isFile()).toBe(true);
  });
  it("should return undefined for an invalid path", async () => {
    const path = "/invalid/path";
    const statObject = await getStatAsync(path);
    expect(statObject).toBeUndefined();
  });
  it("should return the fingerprint for a valid path", async () => {
    const path = __filename;
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeDefined();
    expect(typeof fingerprint).toBe("string");
  });
  it("should return undefined for an invalid path 2", async () => {
    const path = "/invalid/path";
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeUndefined();
  });
  it("should return an array of file paths", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
  });
  it("should return an array of file paths matching the pattern", async () => {
    const pattern = "*.ts";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.endsWith(".ts"))).toBe(true);
  });
  it("should return an empty array if no files match the pattern", async () => {
    const pattern = "*.docx";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should return an array of file paths filtered by the custom filter function", async () => {
    const filter = (name) => name.includes("spec");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.includes("spec"))).toBe(true);
  });
  it("should return an empty array if no files pass the custom filter function", async () => {
    const filter = (name) => name.includes("xyz");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should ignore hidden files by default", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.every((path) => !path.includes("/."))).toBe(true);
  });
});
//# sourceMappingURL=files-async.spec.js.map